<?php 
add_action('admin_menu', 'spp_isim_item_menu');
function spp_isim_item_menu() {
	//add_submenu_page('edit.php?post_type=single_popover', 'Settings', 'Settings', 'edit_published_posts', 'bp_config', 'bp_config');
	global $spp_isim_settings;

	// Options page with script/css loading on demand
	$spp_isim_settings = add_options_page(SPP_ISIM_PLUGIN_NAME.' Settings', SPP_ISIM_PLUGIN_NAME, 'manage_options', 'spp_isim_config', 'spp_isim_config');
  	add_action( 'load-'.$spp_isim_settings, 'spp_isim_load_features' );
}

// Load features e.g. screen only scripts, contextual help
function spp_isim_load_features() {
	global $spp_isim_settings;
	$screen = get_current_screen();

	// Enqueue scripts if needed
	wp_register_script( 'spp-isim-admin', SPP_ISIM_DIR.'modules/js/admin.js', array('jquery'), '', true );
	wp_enqueue_script( 'spp-isim-admin' );
	wp_enqueue_media();
	wp_enqueue_script( 'wp-color-picker' );
	wp_enqueue_style( 'wp-color-picker' );
	$jsopts = array(
		'spp_isim_plugin_name' => SPP_ISIM_PLUGIN_NAME
		);
	wp_localize_script( 'spp-isim-admin', 'spp_isim_object', $jsopts );
	wp_enqueue_style( 'spp-isim-admin', SPP_ISIM_DIR.'modules/css/admin.css', '', SPP_ISIM_VERSION, 'all' );

	// Load contextual help
	if( $screen->id != $spp_isim_settings )
		return;

	// Remove default tabs
    $screen->remove_help_tabs();

	$screen->add_help_tab(array(
		'id' => 'spp-spv-help', // should be unique
		'title' => 'Special Intstruction',
		'content' => '<b>Yeah! Your help here</b>',
		// Use callback instead of 'content' 
		));
}

// WP Pointer Admin Tooltip - Make sure you use cookie to dismiss
add_action('admin_enqueue_scripts', 'spp_isim_enqueue_pointer_scripts');
function spp_isim_enqueue_pointer_scripts() {
	$dismissed = explode (',', get_user_meta (wp_get_current_user ()->ID, 'dismissed_wp_pointers', true));
    $not_in_array = !in_array ('spp_isim_settings_dismiss', $dismissed);

    if( $not_in_array ) {
	    wp_enqueue_style('wp-pointer');
	    wp_enqueue_script('wp-pointer');
	    //hook the pointer 
	    add_action('admin_print_footer_scripts', 'spp_isim_pointer_footer_scripts' );
	}
}
function spp_isim_pointer_footer_scripts() {
    $pointer_content = '<h3>'.SPP_ISIM_PLUGIN_NAME.'</h3>';
    $pointer_content .= '<p>Configure your settings here.</p>';
?>
   <script type="text/javascript">
   //<![CDATA[
   jQuery(document).ready( function($) {
    //jQuery selector to point to 
    $('#menu-settings').pointer({
        content: '<?php echo $pointer_content; ?>',
        position: 'top',
        close: function() {
            // This function is fired when you click the close button
            $.post (ajaxurl, {
		        pointer: 'spp_isim_settings_dismiss',
		        action: 'dismiss-wp-pointer'
		    });
        }
      }).pointer('open');
   });
   //]]>
   </script>
<?php
}

add_action('admin_init', 'spp_isim_settings_api_init');
function spp_isim_settings_api_init() {
	//Add sections to add field later
	add_settings_section( 'spp_isim_defaults', 'Defaults', 'spp_isim_socialnetwork_settings', 'spp_isim_config' );

	// Add fields
	add_settings_field( 'spp_isim_def_bg_img', 'Background image', 'spp_isim_defbgimg_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_font_design', 'Font', 'spp_isim_font_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_text_settings', 'Text settings', 'spp_isim_text_settings_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field('spp_isim_charbreak', 'Line break', 'spp_isim_charbreak_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_text_position', 'Text position', 'spp_isim_text_position_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_def_brand', 'Branding', 'spp_isim_branding_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_wmtext_settings', 'Branding text settings', 'spp_isim_wmtext_settings_callback', 'spp_isim_config', 'spp_isim_defaults' );
	add_settings_field( 'spp_isim_wmtext_align', 'Branding text align', 'spp_isim_wmtext_align_callback', 'spp_isim_config', 'spp_isim_defaults' );

	//Register our setting
	register_setting( 'spp_isim_settings_page', 'spp_isim_options', 'spp_isim_validate_settings' );
} //End spp_isim_settings_api_init

// Settings Section Callbacks
function spp_isim_socialnetwork_settings() {
}

// Settings Field Callbacks
function spp_isim_defbgimg_callback() {
	global $spp_isim_opts;
	?>
	<label class="bg-img">
		<div id="cement" class="bgpreview">Cement</div>
		<input type="radio" name="spp_isim_options[defBGimg]" value="cement" <?php checked( $spp_isim_opts['defBGimg'], 'cement', true ); ?>>
	</label>
	<label class="bg-img">
		<div id="creampaper" class="bgpreview">Cream paper</div>
		<input type="radio" name="spp_isim_options[defBGimg]" value="creampaper" <?php checked( $spp_isim_opts['defBGimg'], 'creampaper', true ); ?>>
	</label>
	<label class="bg-img">
		<div id="lightwood" class="bgpreview">Light wood</div>
		<input type="radio" name="spp_isim_options[defBGimg]" value="lightwood" <?php checked( $spp_isim_opts['defBGimg'], 'lightwood', true ); ?>>
	</label>
	<label class="bg-img">
		<div id="warmwood" class="bgpreview">Warm wood</div>
		<input type="radio" name="spp_isim_options[defBGimg]" value="warmwood" <?php checked( $spp_isim_opts['defBGimg'], 'warmwood', true ); ?>>
	</label>
	<p>Or...</p>
	<?php 
	// If custombg option is not empty, display image
	if( !empty( $spp_isim_opts['custombg'] ) ) {
		?>
		<div id="save-reminder">Remember to save!</div>
		<div id="current-custom-bg">
		<p>Currently using this custom image (overrides settings above) <span id="rmcustombg"><span id="x">X</span> <span id="rm">Remove</span></span></p>
		<p><img src="<?php echo $spp_isim_opts['custombg']; ?>"></p>
		</div>
		<?php
	}
	?>
	<p><a href="#" class="spp-isim-open-media button button-primary">Upload your own</a> <input type="text" name="spp_isim_options[custombg]" class="regular-text" id="spp-isim-custom-bg" value="<?php if( !empty( $spp_isim_opts['custombg'] ) ) { echo esc_url( $spp_isim_opts['custombg'] ); } ?>"> <small>(jpg or png only)</small></p>
	<?php
}
function spp_isim_font_callback() {
	global $spp_isim_opts;
	?>
	<ul class="font">
		<li id="craftygirls"><label>Crafty Girls<br><input type="radio" name="spp_isim_options[font]" value="CraftyGirls" <?php checked( $spp_isim_opts['font'], 'CraftyGirls', true ); ?>></label></li>
		<li id="dancingscript"><label>Dancing Script<br><input type="radio" name="spp_isim_options[font]" value="DancingScript-Regular" <?php checked( $spp_isim_opts['font'], 'DancingScript-Regular', true ); ?>></label></li>
		<li id="lobster"><label>Lobster<br><input type="radio" name="spp_isim_options[font]" value="Lobster" <?php checked( $spp_isim_opts['font'], 'Lobster', true ); ?>></label></li>
		<li id="oswald"><label>Oswald<br><input type="radio" name="spp_isim_options[font]" value="Oswald-Regular" <?php checked( $spp_isim_opts['font'], 'Oswald-Regular', true ); ?>></label></li>
		<li id="pacifico"><label>Pacifico<br><input type="radio" name="spp_isim_options[font]" value="Pacifico" <?php checked( $spp_isim_opts['font'], 'Pacifico', true ); ?>></label></li>
		<li id="playfairdisplay"><label>Playfair Display<br><input type="radio" name="spp_isim_options[font]" value="PlayfairDisplay-Regular" <?php checked( $spp_isim_opts['font'], 'PlayfairDisplay-Regular', true ); ?>></label></li>
		<li id="pt_sans_narrow"><label>PT Sans Narrow<br><input type="radio" name="spp_isim_options[font]" value="PT_Sans-Narrow-Web-Bold" <?php checked( $spp_isim_opts['font'], 'PT_Sans-Narrow-Web-Bold', true ); ?>></label></li>
		<li id="raleway"><label>Raleway<br><input type="radio" name="spp_isim_options[font]" value="Raleway-Bold" <?php checked( $spp_isim_opts['font'], 'Raleway-Bold', true ); ?>></label></li>
		<li id="shadowsintolight"><label>Shadows Into Light<br><input type="radio" name="spp_isim_options[font]" value="ShadowsIntoLight" <?php checked( $spp_isim_opts['font'], 'ShadowsIntoLight', true ); ?>></label></li>
		<li id="specialelite"><label>Special Elite<br><input type="radio" name="spp_isim_options[font]" value="SpecialElite" <?php checked( $spp_isim_opts['font'], 'SpecialElite', true ); ?>></label></li>
	</ul>
	<?php
}
function spp_isim_text_settings_callback() {
	global $spp_isim_opts;
	?>
	<label>Size: <input type="text" id="font-size" class="small-text" name="spp_isim_options[font_size]" value="<?php if( !empty( $spp_isim_opts['font_size'] ) ) { echo stripslashes( $spp_isim_opts['font_size'] ); } ?>"></label>
	<label>Color: <input type="text" id="textColor" class="color-picker regular-text" name="spp_isim_options[textColor]" value="<?php if( !empty( $spp_isim_opts['textColor'] ) ) { echo stripslashes( $spp_isim_opts['textColor'] ); } ?>"></label>
	<?php
}
function spp_isim_charbreak_callback() {
	global $spp_isim_opts;
	?>
	<input type="text" name="spp_isim_options[charbreak]" id="charbreak" class="small-text" value="<?php if( !empty( $spp_isim_opts['charbreak'] ) ) { echo stripslashes( $spp_isim_opts['charbreak'] ); } ?>"><br><small>Break text after this many characters</small>
	<?php
}
function spp_isim_text_position_callback() {
	global $spp_isim_opts;
	?>
	<label>Top Align: <input type="radio" id="position" name="spp_isim_options[position]" value="1" <?php checked( $spp_isim_opts['position'], '1', true ); ?>></label>
	<label>Middle Align: <input type="radio" id="position" name="spp_isim_options[position]" value="0" <?php checked( $spp_isim_opts['position'], '0', true ); ?>></label>
	<label>Bottom Align: <input type="radio" id="position" name="spp_isim_options[position]" value="2" <?php checked( $spp_isim_opts['position'], '2', true ); ?>></label>
	<?php
}
function spp_isim_branding_callback() {
	global $spp_isim_opts;
	?>
	<input type="text" name="spp_isim_options[branding]" value="<?php if( !empty( $spp_isim_opts['branding'] ) ) { echo stripslashes( $spp_isim_opts['branding'] ); } ?>" id="branding" class="regular-text">
	<?php
}
function spp_isim_wmtext_settings_callback() {
	global $spp_isim_opts;
	?>
	<label>Size: <input type="text" id="wm-font-size" class="small-text" name="spp_isim_options[wmfont_size]" value="<?php if( !empty( $spp_isim_opts['wmfont_size'] ) ) { echo stripslashes( $spp_isim_opts['wmfont_size'] ); } ?>"></label>
	<label>Color: <input type="text" id="wmtextColor" class="color-picker regular-text" name="spp_isim_options[wmtextColor]" value="<?php if( !empty( $spp_isim_opts['wmtextColor'] ) ) { echo stripslashes( $spp_isim_opts['wmtextColor'] ); } ?>"></label>
	<?php
}
function spp_isim_wmtext_align_callback() {
	global $spp_isim_opts;
	?>
	<label>Left: <input type="radio" id="wm-ctr-align" name="spp_isim_options[wmtextAlign]" value="0" <?php checked($spp_isim_opts['wmtextAlign'], '0', true ); ?>></label>
	<label>Center: <input type="radio" id="wm-ctr-align" name="spp_isim_options[wmtextAlign]" value="1" <?php checked($spp_isim_opts['wmtextAlign'], '1', true ); ?>></label>
	<label>Right: <input type="radio" id="wm-ctr-align" name="spp_isim_options[wmtextAlign]" value="2" <?php checked($spp_isim_opts['wmtextAlign'], '2', true ); ?>></label>
	<?php
}
// Validate input
function spp_isim_validate_settings( $input ) {
	$spp_isim_opts = get_option( 'spp_isim_options' );

	// Validate and sanitize
	$allowed_bg = array( 'cement', 'creampaper', 'lightwood', 'warmwood' );
	$defBGimg = ( in_array($input['defBGimg'], $allowed_bg) ) ? $input['defBGimg']  : 'lightwood'  ;
	$custombg = ( empty( $input['custombg'] ) ) ? '' : esc_url_raw( $input['custombg'] );
	$allowed_fonts = array( 'CrafyGirls', 'DancingScript-Regular', 'Lobster', 'Oswald-Regular', 'Pacifico', 'PlayfairDisplay-Regular', 'PT_Sans-Narrow-Web-Bold', 'Raleway-Bold', 'ShadowsIntoLight', 'SpecialElite');
	$font = ( in_array( $input['font'], $allowed_fonts ) ) ? $input['font'] : '' ;
	$font_size = ( !empty( $input['font_size'] ) && is_numeric( $input['font_size'] ) ) ? sanitize_text_field( $input['font_size'] ) : '20' ;
	$allowed_position = array( '0', '1', '2' );
	$position = ( !empty( $input['position'] ) && in_array( $input['position'], $allowed_position ) ) ? $input['position'] : '0' ;
	$textColor = ( isset( $input['textColor'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['textColor'] ) == '1' ) ? $input['textColor'] : '#000000' ;
	$charbreak = ( !empty( $input['charbreak'] ) ) ? stripslashes( $input['charbreak'] ) : '25' ;
	$branding = ( empty( $input['branding'] ) ) ? '' : sanitize_text_field( $input['branding'] );
	$wmfont_size = ( !empty( $input['wmfont_size'] ) && is_numeric( $input['wmfont_size'] ) ) ? sanitize_text_field( $input['wmfont_size'] ) : '10' ;
	$wmtextAlign = ( !empty( $input['wmtextAlign'] ) && in_array( $input['wmtextAlign'], $allowed_position ) ) ? $input['wmtextAlign'] : '0' ;
	$wmtextColor = ( isset( $input['wmtextColor'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['wmtextColor'] ) == '1' ) ? $input['wmtextColor'] : '#000000' ;

	// Build array to save
	$valid_input = array(
		'defBGimg' => $defBGimg,
		'custombg' => $custombg,
		'font' => $font,
		'font_size' => $font_size,
		'position' => $position,
		'textColor' => $textColor,
		'charbreak' => $charbreak,
		'branding' => $branding,
		'wmfont_size' => $wmfont_size,
		'wmtextAlign' => $wmtextAlign,
		'wmtextColor' => $wmtextColor
		);
	
	return $valid_input;
}

// Callback for screen output
function spp_isim_config(){

?>
<div class="wrap">
<h2><?php echo SPP_ISIM_PLUGIN_NAME; ?> Settings</h2>
<?php settings_errors( 'spp_isim_options' ); ?>
<form method="POST" action="options.php">
<?php
	//pass slug name of page, also referred to in Settings API as option group name
	settings_fields( 'spp_isim_settings_page' );	
	do_settings_sections( 'spp_isim_config' ); 	//pass slug name of page
	submit_button();
?>
</form>
  
</div>
<?php 
}
?>